@@ -15,7 +15,7 @@
 
 """
 The ``jupyter`` module contains functions to support the use of Text Extensions for Pandas
- in Jupyter notebooks.
+in Jupyter notebooks.
 """
 ################################################################################
 # jupyter module
@@ -27,5 +27,6 @@ The ``jupyter`` module contains functions to support the use of Text Extensions
 # library.
 from text_extensions_for_pandas.jupyter.span import pretty_print_html
 from text_extensions_for_pandas.jupyter.misc import run_with_progress_bar
+from text_extensions_for_pandas.jupyter.widget import DataFrameWidget
 
-__all__ = ["span", "misc"]
\ No newline at end of file
+__all__ = ["pretty_print_html", "run_with_progress_bar", "DataFrameWidget"]
\ No newline at end of file
