@@ -1,5 +1,5 @@
 // Increment the version to invalidate the cached script
-const VERSION = 0.77
+const VERSION = 0.79
 const global_stylesheet = document.head.querySelector("style.span-array-css")
 const local_stylesheet = document.currentScript.parentElement.querySelector("style.span-array-css")
 
@@ -32,7 +32,7 @@ if(window.SpanArray == undefined || window.SpanArray.VERSION == undefined || win
         out = out.replace(/&/g, "&amp;")
         out = out.replace(/</g, "&lt;")
         out = out.replace(/>/g, "&gt;")
-        out = out.replace(/\$/g, "&#36;")
+        out = out.replace(/\$/g, "<span>&#36;</span>")
         out = out.replace(/"/g, "&quot;")
         out = out.replace(/(\r|\n)/g, "<br>")
         return out;
@@ -43,9 +43,9 @@ if(window.SpanArray == undefined || window.SpanArray.VERSION == undefined || win
      *  Used by mark relationship algorithm.
      */
     function compareSpanArrays(a, b) {
-        const start_diff = a[0] - b[0]
+        const start_diff = a.begin - b.begin
         if(start_diff == 0) {
-            return b[1] - a[1]
+            return b.end - a.end
         }
         return start_diff;
     }
@@ -61,9 +61,10 @@ if(window.SpanArray == undefined || window.SpanArray.VERSION == undefined || win
 
             // For each doc, generate a lookup map for quick ID access
             this.docs = this.docs.map(doc => {
+                doc.span_objects = Span.arrayFromSpanArray(doc.doc_spans)
                 doc.lookup_table = {}
-                doc.doc_spans.forEach(doc_span => {
-                    doc.lookup_table[doc_span.id] = doc_span
+                doc.span_objects.forEach(span => {
+                    doc.lookup_table[span.id] = span
                 })
                 return doc
             })
@@ -105,13 +106,14 @@ if(window.SpanArray == undefined || window.SpanArray.VERSION == undefined || win
         // Creates an ordered list of entries from a list of spans with struct [begin, end]
         static arrayFromSpanArray(spanArray) {
             let entries = []
-            let id = 0
-            
-            spanArray.sort(compareSpanArrays)
-            .forEach(span => {
-                entries.push(new Span(id, span[0], span[1]))
-                id += 1
-            })
+            let span;
+            for(let i = 0; i < spanArray.length; i++)
+            {
+                span = spanArray[i];
+                entries.push(new Span(i, span[0], span[1]))
+            }
+
+            entries = entries.sort(compareSpanArrays)
 
             let set;
             for(let i = 0; i < entries.length; i++) {
@@ -186,7 +188,7 @@ if(window.SpanArray == undefined || window.SpanArray.VERSION == undefined || win
     function getDocumentFragment(doc, show_offsets) {
 
         const doc_text = doc.doc_text;
-        const entries = doc.doc_spans;
+        const entries = doc.span_objects;
 
         let frag = document.createDocumentFragment()
         
@@ -200,6 +202,7 @@ if(window.SpanArray == undefined || window.SpanArray.VERSION == undefined || win
                 <th></th>
                 <th>begin</th>
                 <th>end</th>
+                ${(doc['doc_token_spans'] != undefined) ? '<th>begin token</th> <th>end token</th>' : ''}
                 <th>context</th>
             </tr>
             </thead>`
@@ -221,13 +224,14 @@ if(window.SpanArray == undefined || window.SpanArray.VERSION == undefined || win
                 row.innerHTML += `
                 <td>
                     <div class='sa-table-controls'>
-                    <button data-control='visibility' style='width:1em'><svg style='display:block;margin:0.2em auto;' xmlns="http://www.w3.org/2000/svg" viewBox="0 0 576 512"><!-- Font Awesome Free 5.15.3 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License) --><path d="M572.52 241.4C518.29 135.59 410.93 64 288 64S57.68 135.64 3.48 241.41a32.35 32.35 0 0 0 0 29.19C57.71 376.41 165.07 448 288 448s230.32-71.64 284.52-177.41a32.35 32.35 0 0 0 0-29.19zM288 400a144 144 0 1 1 144-144 143.93 143.93 0 0 1-144 144zm0-240a95.31 95.31 0 0 0-25.31 3.79 47.85 47.85 0 0 1-66.9 66.9A95.78 95.78 0 1 0 288 160z"/></svg></button>
-                    <button data-control='highlight' style='width:1em'><svg style='display:block;margin:0.2em auto;' xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><!-- Font Awesome Free 5.15.3 by @fontawesome - https://fontawesome.com License - https://fontawesome.com/license/free (Icons: CC BY 4.0, Fonts: SIL OFL 1.1, Code: MIT License) --><path d="M256 160c-52.9 0-96 43.1-96 96s43.1 96 96 96 96-43.1 96-96-43.1-96-96-96zm246.4 80.5l-94.7-47.3 33.5-100.4c4.5-13.6-8.4-26.5-21.9-21.9l-100.4 33.5-47.4-94.8c-6.4-12.8-24.6-12.8-31 0l-47.3 94.7L92.7 70.8c-13.6-4.5-26.5 8.4-21.9 21.9l33.5 100.4-94.7 47.4c-12.8 6.4-12.8 24.6 0 31l94.7 47.3-33.5 100.5c-4.5 13.6 8.4 26.5 21.9 21.9l100.4-33.5 47.3 94.7c6.4 12.8 24.6 12.8 31 0l47.3-94.7 100.4 33.5c13.6 4.5 26.5-8.4 21.9-21.9l-33.5-100.4 94.7-47.3c13-6.5 13-24.7.2-31.1zm-155.9 106c-49.9 49.9-131.1 49.9-181 0-49.9-49.9-49.9-131.1 0-181 49.9-49.9 131.1-49.9 181 0 49.9 49.9 49.9 131.1 0 181z"/></svg></button>
+                    <button data-control='visibility' style='width:1em'><svg style='display:block;margin:0.2em auto;' xmlns="http://www.w3.org/2000/svg" viewBox="0 0 576 512"><path d="M572.52 241.4C518.29 135.59 410.93 64 288 64S57.68 135.64 3.48 241.41a32.35 32.35 0 0 0 0 29.19C57.71 376.41 165.07 448 288 448s230.32-71.64 284.52-177.41a32.35 32.35 0 0 0 0-29.19zM288 400a144 144 0 1 1 144-144 143.93 143.93 0 0 1-144 144zm0-240a95.31 95.31 0 0 0-25.31 3.79 47.85 47.85 0 0 1-66.9 66.9A95.78 95.78 0 1 0 288 160z"/></svg></button>
+                    <button data-control='highlight' style='width:1em'><svg style='display:block;margin:0.2em auto;' xmlns="http://www.w3.org/2000/svg" viewBox="0 0 512 512"><path d="M256 160c-52.9 0-96 43.1-96 96s43.1 96 96 96 96-43.1 96-96-43.1-96-96-96zm246.4 80.5l-94.7-47.3 33.5-100.4c4.5-13.6-8.4-26.5-21.9-21.9l-100.4 33.5-47.4-94.8c-6.4-12.8-24.6-12.8-31 0l-47.3 94.7L92.7 70.8c-13.6-4.5-26.5 8.4-21.9 21.9l33.5 100.4-94.7 47.4c-12.8 6.4-12.8 24.6 0 31l94.7 47.3-33.5 100.5c-4.5 13.6 8.4 26.5 21.9 21.9l100.4-33.5 47.3 94.7c6.4 12.8 24.6 12.8 31 0l47.3-94.7 100.4 33.5c13.6 4.5 26.5-8.4 21.9-21.9l-33.5-100.4 94.7-47.3c13-6.5 13-24.7.2-31.1zm-155.9 106c-49.9 49.9-131.1 49.9-181 0-49.9-49.9-49.9-131.1 0-181 49.9-49.9 131.1-49.9 181 0 49.9 49.9 49.9 131.1 0 181z"/></svg></button>
                     </div>
                 </td>
                 <td><b>${entry.id.toString()}</b></td>
                 <td>${entry.begin}</td>
                 <td>${entry.end}</td>
+                ${(doc.doc_token_spans != undefined) ? `<td>${doc.doc_token_spans[entry.id][0]}</td><td>${doc.doc_token_spans[entry.id][1]}</td>` : ''}
                 <td>${sanitize(doc_text.substring(entry.begin, entry.end))}</td>`
 
                 tbody.appendChild(row)
